@@ -5,20 +5,22 @@
 import argparse
 import io
 import os
-import pytest
 import subprocess
 import tempfile
-from unittest.mock import patch, call
+from unittest.mock import call, patch
+
+import pytest
 import yaml
 
+
 from op_env._cli import parse_argv, process_args
 from op_env.op import (
-    op_lookup,
-    op_smart_lookup,
     _op_fields_to_try,
-    TooManyEntriesOPLookupError,
     NoEntriesOPLookupError,
     NoFieldValueOPLookupError,
+    op_lookup,
+    op_smart_lookup,
+    TooManyEntriesOPLookupError,
 )
 
 
@@ -174,22 +176,34 @@ def test_process_args_rejects_non_run():
             process_args(args)
 
 
+def test_fields_to_try_breaks_on_double_underscore_and_underscore():
+    with patch('op_env.op.subprocess'):  # for safety
+        out = _op_fields_to_try('ABC__FLOOGLE_BAR')
+        assert out == ['abc__floogle_bar', 'floogle_bar', 'bar', 'password']
+
+
+def test_fields_to_try_breaks_on_double_underscore():
+    with patch('op_env.op.subprocess'):  # for safety
+        out = _op_fields_to_try('ABC__FLOOGLE')
+        assert out == ['abc__floogle', 'floogle', 'password']
+
+
 def test_fields_to_try_conversion_username():
     with patch('op_env.op.subprocess'):  # for safety
         out = _op_fields_to_try('ABC_USER')
-        assert out == ['username', 'password']
+        assert out == ['abc_user', 'user', 'username', 'password']
 
 
 def test_fields_to_try_multiple_words():
     with patch('op_env.op.subprocess'):  # for safety
         out = _op_fields_to_try('ABC_FLOOGLE')
-        assert out == ['floogle', 'password']
+        assert out == ['abc_floogle', 'floogle', 'password']
 
 
 def test_fields_to_try_simple():
     with patch('op_env.op.subprocess'):  # for safety
         out = _op_fields_to_try('ABC')
-        assert out == ['password']
+        assert out == ['abc', 'password']
 
 
 def test_op_lookup_no_field_value():
